import { Component, OnInit, ViewChild } from '@angular/core';
import { IDataOptions, IDataSet, FieldListService, PivotView, IAxisSet, IPivotValues } from '@syncfusion/ej2-angular-pivotview';
import { GridSettings } from '@syncfusion/ej2-pivotview/src/pivotview/model/gridsettings';
import { enableRipple } from '@syncfusion/ej2-base';
enableRipple(false);

/**
 * Pivot Table Default Sample.
 */

@Component({
  selector: 'app-root',
  styleUrls: ['app.component.css'],
  templateUrl: 'app.component.html',
  providers: [FieldListService],
})

export class AppComponent {
  public dataSourceSettings: IDataOptions;
  public gridSettings: GridSettings;
  public columnGrandTotalIndex;
  public rowGrandTotalIndex;

  @ViewChild('pivotview', { static: false })
  public pivotGridObj: PivotView;

  ngOnInit(): void {
    this.gridSettings = {
      columnWidth: 140,
    } as GridSettings;

    this.dataSourceSettings = {
      enableSorting: true,
	  columns: [{name:'Quarter'},{ name: 'Date' }],
      values: [{ name: 'Qty 1', caption: 'Units Sold' }, { name: 'Qty 2', caption: 'Units Amount' }],
      dataSource: this.getPivotData(),
      rows: [{ name: 'Product' }],
      expandAll: false,
      filters: [],
    };
  }

  headerCell(args: any): void {
    if (args.node.innerText) {
      var month = args.node.innerText.split('-')[1];
      switch (month) {
        case '01':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Jan';
          break;
        case '02':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Feb';
          break;
        case '03':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Mar';
          break;
        case '04':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Apr';
          break;
        case '05':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'May';
          break;
        case '06':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Jun';
          break;
        case '07':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Jul';
          break;
        case '08':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Aug';
          break;
        case '09':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Sep';
          break;
        case '10':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Oct';
          break;
        case '11':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Nov';
          break;
        case '12':
          args.node.innerText = args.node.innerText.split('-')[0] + '-' + 'Dec';
          break;
      }
    }
  }

  enginePopulated(args: any): void {
    this.pivotGridObj.grid.headerCellInfo = this.headerCell.bind(this);
  }

  getPivotData(): IDataSet[] {
     let pivotData: IDataSet[] = [
      {
        'Date': '2015-01',
        'Quarter':'2015-Q1',
        'Product': 'File Folder',
        'Qty 1': 8,
        'Qty 2': 8
      },
      {
        'Date': '2015-03',
        'Quarter':'2015-Q1',
        'Product': 'File Folder',
        'Qty 1': 97,
        'Qty 2': 97
      },
      {
        'Date': '2016-07',
        'Quarter':'2016-Q3',
        'Product': 'Paper',
        'Qty 1': 20,
        'Qty 2': 20
      },
      {
        'Date': '2017-12',
        'Quarter':'2017-Q4',
        'Product': 'Paper',
        'Qty 1': 10,
        'Qty 2': 10
      },
      {
        'Date': '2018-09',
        'Quarter':'2018-Q3',
        'Product': 'Paper',
        'Qty 1': 20,
        'Qty 2': 20
      },
      {
        'Date': '2009-01',
        'Quarter':'2009-Q1',
        'Product': 'Pens'
      },];

    return pivotData;
  }
}